# Contributing to lftools

Thank you for your interest in the LF Tools project. This is a project repo
for one of the Linux Foundation Release Engineering team's tools projects.

## How to contribute

Contributions to this project are welcome. This project uses [Gerrit][1] as our
code review system. Please submit patch contributions there. You can
use [git-review][2] to submit patches to this project. You will need to first
get a [LFID][3] account before you can begin submitting patches.

## Reporting a Bug

Please report Feature requests and Bugs to our [Jira][4] system under the
RELENG project.

[1]: https://gerrit.linuxfoundation.org/infra/#/admin/projects/releng/lftools

[2]: https://docs.openstack.org/infra/git-review/

[3]: https://identity.linuxfoundation.org/

[4]: https://jira.linuxfoundation.org/projects/RELENG
